==> bigloo_1.9c.orig.tar.gz: bigloo1.9c/recette/module.scm <==
;* --------------------------------------------------------------------*/
;*    Copyright (c) 1992-1998 by Manuel Serrano. All rights reserved.  */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \   /  '                               */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome. Send them to                                          */
;*        Manuel Serrano -- Manuel.Serrano@unice.fr                    */
;*-------------------------------------------------------------------- */
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/recette/module.scm                   */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Sun Jan 29 10:56:02 1995                          */
;*    Last change :  Fri Feb  6 16:40:03 1998 (serrano)                */
;*    -------------------------------------------------------------    */
;*    Les tests d'exportations                                         */
;*=====================================================================*/

(module module
   (include "test.sch")
   (import  (import1 "import1.scm")
	    (import2 "import2.scm")
	    (main "main.scm"))
   (extern  (macro c-dummy1 (::string) "printf"))
   (export  fun
	    (test-modulel)
	    c-dummy1
	    c-dummy2)
   (extern  (macro c-dummy2 (::string) "printf")))

;*---------------------------------------------------------------------*/
;*    Le bug signale par David Gurr                                    */
;*---------------------------------------------------------------------*/
(define (foo x)
   x)

(define fun foo)

;*---------------------------------------------------------------------*/
;*    Bug pointed out by David Fox                                     */
;*---------------------------------------------------------------------*/
(define c-dummy1 #f)
(define c-dummy2 #f)

;*---------------------------------------------------------------------*/
;*    Le pbm de l'init avec le lecteur                                 */
;*---------------------------------------------------------------------*/
(define read 'bogus)
(set! read "re-bogus")

(define (init/read-test)
   (cons 'init '(1 2 3 4)))
 
;*---------------------------------------------------------------------*/
;*    test-modulel ...                                                 */
;*---------------------------------------------------------------------*/
(define (test-modulel)
   (test-module "module" "module.scm" #f)
   (test "@" (@ x import1) 1)
   (test "@" (@ x import2) 2)
   (test "@" (or (eq? x (@ x import1)) (eq? x (@ x import2))) #t)
   (test "init/read" (init/read-test) '(init . (1 2 3 4))))

==> bigloo_2.8c.orig.tar.gz: bigloo2.8c/recette/module.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/recette/module.scm                   */
;*    -------------------------------------------------------------    */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Sun Jan 29 10:56:02 1995                          */
;*    Last change :  Sat Jun 15 16:23:50 2002 (serrano)                */
;*    -------------------------------------------------------------    */
;*    Les tests d'exportations                                         */
;*=====================================================================*/

(module module
   (include "test.sch")
   (import  (x import1 "import1.scm")
	    (y z import1 "import1.scm")
	    (import2 "import2.scm")
	    (main "main.scm"))
   (extern  (macro c-dummy1 (::string) "printf"))
   (export  fun
	    (test-modulel)
	    c-dummy1
	    c-dummy2)
   (extern  (macro c-dummy2 (::string) "printf")))

;*---------------------------------------------------------------------*/
;*    Le bug signale par David Gurr                                    */
;*---------------------------------------------------------------------*/
(define (foo x)
   x)

(define fun foo)

;*---------------------------------------------------------------------*/
;*    Bug pointed out by David Fox                                     */
;*---------------------------------------------------------------------*/
(define c-dummy1 #f)
(define c-dummy2 #f)

;*---------------------------------------------------------------------*/
;*    Le pbm de l'init avec le lecteur                                 */
;*---------------------------------------------------------------------*/
(define read 'bogus)
(set! read "re-bogus")

(define (init/read-test)
   (cons 'init '(1 2 3 4)))
 
;*---------------------------------------------------------------------*/
;*    test-modulel ...                                                 */
;*---------------------------------------------------------------------*/
(define (test-modulel)
   (test-module "module" "module.scm")
   (test "@" (@ x import1) 1)
   (test "@" (@ x import2) 2)
   (test "@" (or (eq? x (@ x import1)) (eq? x (@ x import2))) #t)
   (test "inline/type" (z) 1)
   (test "init/read" (init/read-test) '(init . (1 2 3 4))))
